package com.example.controller;

import com.example.config.annotation.IgnoreAuth;
import com.example.entity.WzHouseContracEntity;
import com.example.entity.WzHouseContractOutEntity;
import com.example.service.WzHouseContractOutService;
import com.example.utils.PageMap;
import com.example.utils.PageUtils;
import com.example.utils.Query;
import com.example.utils.R;
import com.example.utils.excel.ExcelExport;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletResponse;
import java.text.DateFormat;
import java.text.DecimalFormat;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 房屋出租(合同管理)
 */
@RestController
@RequestMapping("/house-car/house/dist/api/WzHouseContractOut")
public class WzHouseContractOutController {

    @Autowired
    private WzHouseContractOutService wzHouseContractOutService;

    @RequestMapping("/list")
    @IgnoreAuth
    public R list(@RequestBody PageMap pageMap) {
        //查询列表数据
        Query query = new Query(pageMap);
        List<WzHouseContractOutEntity> list = wzHouseContractOutService.queryList(query);
        Query query1 = new Query(pageMap);
        int total = wzHouseContractOutService.queryTotal(query1);
        PageUtils pageUtil = new PageUtils(list, total, query.getLimit(), query.getPage());
        return R.ok().put("page", pageUtil);
    }

    @RequestMapping("/echartList")
    @IgnoreAuth
    public R echartList(@RequestBody PageMap pageMap) {
        //查询列表数据
        Query query = new Query(pageMap);
        List<WzHouseContracEntity> wzHouseContracEntityList = wzHouseContractOutService.queryList(pageMap.getMap());

        WzHouseContracEntity province=new WzHouseContracEntity();
        province.setCity("全省");

        Map<String,List<WzHouseContracEntity>> map=new HashMap<>();
        for (WzHouseContracEntity leaveUseVo : wzHouseContracEntityList) {
            List<WzHouseContracEntity> list;
            if(map.get(leaveUseVo.getCity())!=null){
                list=map.get(leaveUseVo.getCity());
                list.add(leaveUseVo);
            }else{
                list=new ArrayList<>();
                list.add(leaveUseVo);
            }
            map.put(leaveUseVo.getCity(),list);
        }
        List<WzHouseContracEntity> resultList=new ArrayList<>();
        List<WzHouseContracEntity> cityList=new ArrayList<>();

        double allContractQuantity=0l;
        double allNoTaxContractAmount=0l;
        double allRentArea=0l;
        double allUnitPricePerSquareMeter=0l;

        for(Map.Entry<String,List<WzHouseContracEntity>> entry:map.entrySet()){
            List<WzHouseContracEntity> list=entry.getValue();
            double contractQuantity=0l;
            double noTaxContractAmount=0l;
            double rentArea=0l;
            double unitPricePerSquareMeter=0l;
            for (WzHouseContracEntity leaveUseVo : list) {
                contractQuantity+=leaveUseVo.getContractQuantity();
                noTaxContractAmount+=leaveUseVo.getNoTaxContractAmount();
                rentArea+=leaveUseVo.getRentArea();
                unitPricePerSquareMeter+=leaveUseVo.getUnitPricePerSquareMeter();

                allContractQuantity+=leaveUseVo.getContractQuantity();
                allNoTaxContractAmount+=leaveUseVo.getNoTaxContractAmount();
                allRentArea+=leaveUseVo.getRentArea();
                allUnitPricePerSquareMeter+=leaveUseVo.getUnitPricePerSquareMeter();
            }
            cityList.add(list.get(0));
        }
        province.setContractQuantity(allContractQuantity);
        province.setNoTaxContractAmount(formatDouble(allNoTaxContractAmount));
        province.setRentArea(allRentArea);
        province.setUnitPricePerSquareMeter(allUnitPricePerSquareMeter);
        province.setChildren(cityList);
        resultList.add(province);

        int total = wzHouseContractOutService.queryTotal(query);
        PageUtils pageUtil = new PageUtils(resultList, total, query.getLimit(), query.getPage());
        return R.ok().put("page", pageUtil);
    }

    /**
     * 清单excel
     */
    @GetMapping("/excel")
    @IgnoreAuth
    public void excel(String name,String buildingNameAlias,String city,String county, HttpServletResponse response) {
        Map<String, Object> map = new HashMap<>();
        if (buildingNameAlias != null) {
            map.put("buildingNameAlias", buildingNameAlias);
        }
        if (city != null) {
            map.put("city", city);
        }
        if (county != null) {
            map.put("county", county);
        }

        DateFormat df = new SimpleDateFormat("yyyyMMddHHmmss");
        ExcelExport ee1 = new ExcelExport("报表" + df.format(new Date()));

        try {
            List<WzHouseContractOutEntity> list = wzHouseContractOutService.queryList(map);
            List<Object> colList;
            List<Object[]> allList = new ArrayList();
            for (int i = 0; i < list.size(); i++) {
                colList = new ArrayList();
                colList.add(list.get(i).getContractNumber());
                colList.add(list.get(i).getContractSerialNumber());
                colList.add(list.get(i).getCreateDate());
                colList.add(list.get(i).getContractStatus());
                colList.add(list.get(i).getContractName());
                colList.add(list.get(i).getUndertakingDepartment());
                colList.add(list.get(i).getUndertaker());
                colList.add(list.get(i).getContactNumber());
                colList.add(list.get(i).getOurSubject());
                colList.add(list.get(i).getFullNameOfThTenant());
                colList.add(list.get(i).getContractType());
                colList.add(list.get(i).getContractDescription());
                colList.add(list.get(i).getExcludingValueAddedTaxContractAmount());
                colList.add(list.get(i).getContractAmountIncludingVat());
                colList.add(list.get(i).getRate());
                colList.add(list.get(i).getPriceIncreaseMechanism());
                colList.add(list.get(i).getRenPaymentMethod());
                colList.add(list.get(i).getLeaseCategory());
                colList.add(list.get(i).getRentFreeStartDate());
                colList.add(list.get(i).getRentFreeEndDate());
                colList.add(list.get(i).getRentalStartDate());
                colList.add(list.get(i).getRentalEndDate());
                colList.add(list.get(i).getContractLeaseTerm());
                colList.add(list.get(i).getContractRentalArea());
                colList.add(list.get(i).getDebt());
                colList.add(list.get(i).getEndTime());
                colList.add(list.get(i).getEndReason());
                colList.add(list.get(i).getSubordinateUnits());
                colList.add(list.get(i).getResourceType());
                colList.add(list.get(i).getBuildingAlias());
                allList.add(colList.toArray());
            }

            String[] header = new String[]{
                    "合同编号",
                    "合同流水号",
                    "创建日期",
                    "合同状态",
                    "合同名称",
                    "承办部门",
                    "承办人",
                    "联系电话",
                    "我方主体",
                    "合同类型",
                    "投资主体",
                    "合同说明",
                    "含增值税合同金额",
                    "不含增值税合同额",
                    "税率",
                    "涨价机制",
                    "交租方式",
                    "租赁类别",
                    "免租期起始日期",
                    "免租期终止日期",
                    "出租起始日期",
                    "出租终止日期",
                    "合同租期（月数）",
                    "合同出租面积",
                    "房屋实际产权",
                    "是否有欠款",
                    "终止时间",
                    "终止原因",
                    "所属单位",
                    "资源类型",
                    "建筑/土地别名"
            };
            ee1.addSheetByArray(df.format(new Date()) + "清单", allList, header);
            ee1.export(response);
        } catch (Exception e) {
            e.printStackTrace();
        }

    }


    public double formatDouble(double num){
        double avera=0l;
        try{
            DecimalFormat format2 = new DecimalFormat("#.00");
            String str2 = format2.format(num);
            avera = Double.parseDouble(str2);
        }catch (Exception e){
            e.printStackTrace();
        }
        return avera;
    }

}
