package com.example.controller;

import com.example.config.annotation.IgnoreAuth;
import com.example.entity.WzRentThrMonthEntity;
import com.example.service.WzRentThreeMonthService;
import com.example.utils.PageMap;
import com.example.utils.PageUtils;
import com.example.utils.Query;
import com.example.utils.R;
import com.example.utils.excel.ExcelExport;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletResponse;
import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 房屋出租(合同管理)
 */
@RestController
@RequestMapping("/house-car/house/dist/api/wzRentThreeMonth")
public class WzRentThreeMonthController {

    @Autowired
    private WzRentThreeMonthService wzRentThreeMonthService;

    @RequestMapping("/list")
    @IgnoreAuth
    public R list(@RequestBody PageMap pageMap) {
        //查询列表数据
        Query query = new Query(pageMap);
        if(query.get("statisticalMonth")==null||query.get("statisticalMonth").toString().equals("")){
            String lastTime=wzRentThreeMonthService.getLastStaticMonth();
            query.put("statisticalMonth",lastTime);
        }
        List<WzRentThrMonthEntity> resultList = wzRentThreeMonthService.queryList(query);
        int total = wzRentThreeMonthService.queryTotal(query);
        PageUtils pageUtil = new PageUtils(resultList, total, query.getLimit(), query.getPage());
        return R.ok().put("page", pageUtil);
    }

    /**
     * 清单excel
     */
    @GetMapping("/excel")
    @IgnoreAuth
    public void excel(String statisticalMonth, String buildingNameAlias, String city, String county, HttpServletResponse response) {
        Map<String, Object> map = new HashMap<>();
        if (buildingNameAlias != null) {
            map.put("buildingNameAlias", buildingNameAlias);
        }
        if (city != null) {
            map.put("city", city);
        }
        if (county != null) {
            map.put("county", county);
        }
        if(statisticalMonth==null||statisticalMonth.equals("")||statisticalMonth.equals("undefined")){
            String lastTime=wzRentThreeMonthService.getLastStaticMonth();
            map.put("statisticalMonth",lastTime);
        }else{
            map.put("statisticalMonth",statisticalMonth);
        }
        List<WzRentThrMonthEntity> resultList = wzRentThreeMonthService.queryList(map);

        DateFormat df = new SimpleDateFormat("yyyyMMddHHmmss");
        ExcelExport ee1 = new ExcelExport("出租监控_出租房屋连续3个月存在欠款" + df.format(new Date()));

        List<Object> colList;
        List<Object[]> allList = new ArrayList();
        for (int i = 0; i < resultList.size(); i++) {
            colList = new ArrayList();
            colList.add(resultList.get(i).getMonth());
            colList.add(resultList.get(i).getCity());
            colList.add(resultList.get(i).getCounty());
            colList.add(resultList.get(i).getUserName());
            colList.add(resultList.get(i).getUserAttribute());
            colList.add(resultList.get(i).getDataOne());
            colList.add(WzHouseMaintenaCostController.toThousands(resultList.get(i).getAccumulatedArrears(),true));
            colList.add(resultList.get(i).getUserEncoding());
            allList.add(colList.toArray());

        }
        String[] header = new String[]{
                "统计月份",
                "地市",
                "县区",
                "用户名称",
                "客户属性",
                "欠费时长（月）",
                "累计欠费",
                "用户号码"
        };
        ee1.addSheetByArray(df.format(new Date()) + "清单", allList, header);
        ee1.export(response);
    }

}

