package com.example.controller.house;

import com.example.common.PageVo;
import com.example.common.Rsp;
import com.example.pojo.dto.BuildingIdleStatDto;
import com.example.pojo.dto.HouseAgeStatDto;
import com.example.pojo.dto.ListBuildingDto;
import com.example.pojo.dto.ListBuildingIdleDto;
import com.example.pojo.dto.ListSiteNameDto;
import com.example.pojo.dto.ListSiteNumDto;
import com.example.pojo.vo.BuildingIdleStatVo;
import com.example.pojo.vo.HouseAgeStatVo;
import com.example.pojo.vo.ListBuildingIdleVo;
import com.example.pojo.vo.ListBuildingVo;
import com.example.service.house.HouseWzBuildManageDetailsService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;

@Tag(name = "不动产建筑")
@Slf4j
@RequestMapping("/house-car/house/dist/api/WzBuildManageDetails")
@RestController
public class HouseWzBuildManageDetailsController {
    private final HouseWzBuildManageDetailsService houseWzBuildManageDetailsService;

    public HouseWzBuildManageDetailsController(HouseWzBuildManageDetailsService houseWzBuildManageDetailsService) {
        this.houseWzBuildManageDetailsService = houseWzBuildManageDetailsService;
    }

    @Operation(summary = "空置1000平米以上建筑")
    @PostMapping("/ideList")
    public Rsp<PageVo<ListBuildingIdleVo>> ideList(@Valid @RequestBody ListBuildingIdleDto dto) {
        return houseWzBuildManageDetailsService.ideList(dto);
    }

    @Operation(summary = "空置1000平米以上建筑导出")
    @GetMapping("/ideListExport")
    public void ideListExport(@Valid ListBuildingIdleDto.ListBuildingIdleMapDTO dto) {
        houseWzBuildManageDetailsService.ideListExport(dto);
    }

    @Operation(summary = "查询局址别名列表")
    @PostMapping("/getBuildingNameAlias")
    public Rsp<PageVo<String>> listSiteName(@RequestBody ListSiteNameDto dto) {
        return houseWzBuildManageDetailsService.listSiteName(dto);
    }

    @Operation(summary = "查询局址编号列表")
    @PostMapping("/getBuildingNameCode")
    public Rsp<PageVo<String>> listSiteNum(@RequestBody ListSiteNumDto dto) {
        return houseWzBuildManageDetailsService.listSiteNum(dto);
    }

    @Operation(summary = "查询房产记录")
    @PostMapping("/queryHouseDetail")
    public Rsp<PageVo<ListBuildingVo>> listBuilding(@Valid @RequestBody ListBuildingDto dto) {
        return houseWzBuildManageDetailsService.listBuilding(dto);
    }

    @Operation(summary = "房产记录导出")
    @GetMapping("/queryHouseDetailExport")
    public void listBuildingExport(@Valid ListBuildingDto.ListBuildingMapDTO dto) {
        houseWzBuildManageDetailsService.listBuildingExport(dto);
    }

    @Operation(summary = "房龄统计")
    @PostMapping("/queryHouseYear")
    public Rsp<PageVo<HouseAgeStatVo>> houseAgeStat(@Valid @RequestBody HouseAgeStatDto dto) {
        return houseWzBuildManageDetailsService.houseAgeStat(dto);
    }

    @Operation(summary = "房龄统计导出")
    @GetMapping("/queryHouseYearExport")
    public void queryHouseYearExport(@Valid HouseAgeStatDto.HouseAgeStatMapDTO dto) {
        houseWzBuildManageDetailsService.queryHouseYearExport(dto);
    }

    @Operation(summary = "闲置管理")
    @PostMapping("/list")
    public Rsp<PageVo<BuildingIdleStatVo>> buildingIdleStat(@Valid @RequestBody BuildingIdleStatDto dto) {
        return houseWzBuildManageDetailsService.buildingIdleStat(dto);
    }

    @Operation(summary = "闲置管理导出")
    @GetMapping("/buildingIdleStatExport")
    public void buildingIdleStatExport(@Valid BuildingIdleStatDto.BuildingIdleStatMapDTO dto) {
        houseWzBuildManageDetailsService.buildingIdleStatExport(dto);
    }
}
