package com.example.dao.house;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.example.entity.house.BuildingRepairMonthPo;
import com.example.entity.house.BuildingRepairStatPo;
import com.example.pojo.bo.BuildingRepairStatBo;
import com.example.pojo.bo.ListBuildingRepairMonthBo;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import org.apache.ibatis.annotations.Select;

import java.util.List;

@Mapper
public interface HouseBuildingRepairDao {
    @Select("""
<script>
with
t101 as (
select
    area_no,
    city_no,
    sum(case when repair_type = '项目制维修' then final_cost else 0 end) as xmz,
    sum(case when repair_type = '零星维修' then final_cost else 0 end) as lx,
    sum(case when repair_type = '应急维修' then final_cost else 0 end) as yj,
    sum(final_cost) as hj
from
    house.building_repair_month
where
    year_month <![CDATA[ >= ]]> #{dto.startYearMonth}
    and year_month <![CDATA[ <= ]]> #{dto.endYearMonth}
    and repair_type != '财务预提冲销'
    and area_no is not null
    and area_no != ''
    and city_no is not null
    and city_no != ''
<if test="dto.areaNo != null and dto.areaNo != ''">
  and area_no = #{dto.areaNo}
</if>
<if test="dto.cityNo != null and dto.cityNo != ''">
  and city_no = #{dto.cityNo}
</if>
<if test="dto.investorName != null and dto.investorName != ''">
  and investor_name = #{dto.investorName}
</if>
group by
    area_no,
    city_no
),
t102 as (
select
    b.id as area_no,
    b."name" as area_name,
    a.id as city_no,
    a."name" as city_name,
    coalesce(c.xmz, 0) as xmz,
    coalesce(c.lx, 0) as lx,
    coalesce(c.yj, 0) as yj,
    coalesce(c.hj, 0) as hj
from
    common.organization a
left join common.organization b on
    a.parent_id = b.id
left join t101 c on
    a.id = c.city_no
where
    a.grade = 2
    and a.unhide = 1
<if test="dto.areaNo != null and dto.areaNo != ''">
  and a.parent_id = #{dto.areaNo}
</if>
<if test="dto.cityNo != null and dto.cityNo != ''">
  and a.id = #{dto.cityNo}
</if>
order by
    b.order_num, a.order_num
)
select * from t102
</script>
""")
    List<BuildingRepairStatPo> buildingRepairStat(@Param("dto") BuildingRepairStatBo dto);

    /**
     * 查询不动产自有房产维修
     */
    @Select("""
<script>
with
t101 as (
select
a.year_month,
a.repair_type,
a.content_category,
a.final_cost,
a.investor_name,
a.jz_jzid,
a.area_no,
a.area_name,
a.city_no,
a.city_name,
a.site_id,
a.site_name,
a.site_num,
b.building_name,
b.building_id,
b.first_unit,
b.address,
b.city_level,
b.city_region,
b.area_sector,
b.has_land,
b.housing_acquisition_rate,
b.housing_source,
b.acquisition_date,
b.house_year_began,
b.management_level,
b.building_structure,
b.total_floors,
b.assets_num,
b.assets_tag_num,
b.usage_status,
b.building_use,
b.ownership_status,
b.floor_area,
b.building_area,
b.building_area_self_use,
b.building_area_rent,
b.building_area_idle,
b.building_area_unusable,
b.usable_area,
b.usable_area_self_use,
b.usable_area_rent,
b.usable_area_idle,
b.usable_area_unusable,
b.house_age,
case
    when (coalesce(b.building_area_self_use, 0) + coalesce(b.building_area_rent, 0)) = 0 then null
    else round(a.final_cost / (coalesce(b.building_area_self_use, 0) + coalesce(b.building_area_rent, 0)),
    2)
end as repair_unit_price
from
    house.building_repair_month a
left join house.building_month b on
    a.jz_jzid = b.building_id
    and a.year_month = b.year_month
<choose>
  <when test="dto.yearMonth != null">
    where a.year_month = #{dto.yearMonth}
  </when>
  <otherwise>
    where a.year_month = (select max(year_month) from house.building_repair_month)
  </otherwise>
</choose>
and a.final_cost is not null
<if test="dto.areaNo != null and dto.areaNo != ''">
  and a.area_no = #{dto.areaNo}
</if>
<if test="dto.cityNo != null and dto.cityNo != ''">
  and a.city_no = #{dto.cityNo}
</if>
<if test="dto.siteName != null and dto.siteName != ''">
  and site_name = #{dto.siteName}
</if>
<if test="dto.siteNum != null and dto.siteNum != ''">
  and site_num = #{dto.siteNum}
</if>
<if test="dto.investorName != null and dto.investorName != ''">
  and a.investor_name = #{dto.investorName}
</if>
)
select * from t101
</script>
""")
    List<BuildingRepairMonthPo> listBuildingRepairMonth(Page<BuildingRepairMonthPo> page,
                                                        @Param("dto") ListBuildingRepairMonthBo dto);
}
