package com.example.dao.house;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.example.entity.house.HouseBuildingHighRepairPo;
import com.example.entity.house.HouseBuildingHighSporadicRepairPo;
import com.example.entity.house.HouseBuildingIdleRepairPo;
import com.example.entity.house.HouseBuildingSameRepairFrequencyPo;
import com.example.pojo.bo.ListBuildingHighRepairBo;
import com.example.pojo.bo.ListBuildingHighSporadicRepairBo;
import com.example.pojo.bo.ListBuildingIdleRepairBo;
import com.example.pojo.bo.ListBuildingSameRepairFrequencyBo;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import org.apache.ibatis.annotations.Select;

import java.util.List;

@Mapper
public interface HouseRepairExceptionDao {
    /**
     * 查询不动产自有房产维修高总价统计
     */
    @Select("""
<script>
select
*
from house.building_high_repair
<where>
  <choose>
    <when test="dto.yearMonth != null">
      year_month = #{dto.yearMonth}
    </when>
    <otherwise>
      year_month = (select max(year_month) from house.building_high_repair)
    </otherwise>
  </choose>
  <if test="dto.areaNo != null and dto.areaNo != ''">
    and area_no = #{dto.areaNo}
  </if>
  <if test="dto.cityNo != null and dto.cityNo != ''">
    and city_no = #{dto.cityNo}
  </if>
  <if test="dto.siteNum != null and dto.siteNum != ''">
    and site_num = #{dto.siteNum}
  </if>
  <if test="dto.siteName != null and dto.siteName != ''">
    and site_name = #{dto.siteName}
  </if>
</where>
</script>
""")
    List<HouseBuildingHighRepairPo> listBuildingHighRepair(Page<HouseBuildingHighRepairPo> page,
                                                           @Param("dto") ListBuildingHighRepairBo dto);

    /**
     * 查询不动产自有房产相同维修频次统计
     */
    @Select("""
<script>
select
*
from house.building_same_repair_frequency
<where>
  <choose>
    <when test="dto.yearMonth != null">
      year_month = #{dto.yearMonth}
    </when>
    <otherwise>
      year_month = (select max(year_month) from house.building_same_repair_frequency)
    </otherwise>
  </choose>
  <if test="dto.areaNo != null and dto.areaNo != ''">
    and area_no = #{dto.areaNo}
  </if>
  <if test="dto.cityNo != null and dto.cityNo != ''">
    and city_no = #{dto.cityNo}
  </if>
  <if test="dto.siteNum != null and dto.siteNum != ''">
    and site_num = #{dto.siteNum}
  </if>
  <if test="dto.siteName != null and dto.siteName != ''">
    and site_name = #{dto.siteName}
  </if>
</where>
</script>
""")
    List<HouseBuildingSameRepairFrequencyPo> listBuildingSameRepairFrequency(
            Page<HouseBuildingSameRepairFrequencyPo> page,
            @Param("dto") ListBuildingSameRepairFrequencyBo dto);

    /**
     * 查询不动产自有房产高额零星维修统计
     */
    @Select("""
<script>
select
*
from house.building_high_sporadic_repair
<where>
  <choose>
    <when test="dto.yearMonth != null">
      year_month = #{dto.yearMonth}
    </when>
    <otherwise>
      year_month = (select max(year_month) from house.building_high_sporadic_repair)
    </otherwise>
  </choose>
  <if test="dto.areaNo != null and dto.areaNo != ''">
    and area_no = #{dto.areaNo}
  </if>
  <if test="dto.cityNo != null and dto.cityNo != ''">
    and city_no = #{dto.cityNo}
  </if>
  <if test="dto.siteNum != null and dto.siteNum != ''">
    and site_num = #{dto.siteNum}
  </if>
  <if test="dto.siteName != null and dto.siteName != ''">
    and site_name = #{dto.siteName}
  </if>
</where>
</script>
""")
    List<HouseBuildingHighSporadicRepairPo> ListBuildingHighSporadicRepair(
            Page<HouseBuildingHighSporadicRepairPo> page, @Param("dto") ListBuildingHighSporadicRepairBo dto);

    /**
     * 查询不动产自有房产闲置不可用发生维修费
     */
    @Select("""
<script>
select
*
from house.building_idle_repair
<where>
  <choose>
    <when test="dto.yearMonth != null">
      year_month = #{dto.yearMonth}
    </when>
    <otherwise>
      year_month = (select max(year_month) from house.building_high_repair)
    </otherwise>
  </choose>
  <if test="dto.areaNo != null and dto.areaNo != ''">
    and area_no = #{dto.areaNo}
  </if>
  <if test="dto.cityNo != null and dto.cityNo != ''">
    and city_no = #{dto.cityNo}
  </if>
  <if test="dto.siteNum != null and dto.siteNum != ''">
    and site_num = #{dto.siteNum}
  </if>
  <if test="dto.siteName != null and dto.siteName != ''">
    and site_name = #{dto.siteName}
  </if>
</where>
</script>
""")
    List<HouseBuildingIdleRepairPo> listBuildingIdleRepair(Page<HouseBuildingIdleRepairPo> page,
                                                           @Param("dto") ListBuildingIdleRepairBo dto);
}
