package com.example.entity.house;

import lombok.Data;

import java.math.BigDecimal;
import java.math.RoundingMode;
import java.util.ArrayList;
import java.util.List;

@Data
public class LandIdleStatPo {
    /**
     * 二级组织机构编码
     */
    private String areaNo;
    /**
     * 二级组织机构名称
     */
    private String areaName;
    /**
     * 三级组织机构编码
     */
    private String cityNo;
    /**
     * 三级组织机构名称
     */
    private String cityName;
    /**
     * 闲置建筑数量
     */
    private Integer idleCount;
    /**
     * 土地总面积
     */
    private BigDecimal totalLandAreaSum;
    /**
     * 土地自用面积
     */
    private BigDecimal landAreaSelfUseSum;
    /**
     * 土地不可使用面积
     */
    private BigDecimal landAreaUnusableSum;
    /**
     * 土地出租面积
     */
    private BigDecimal landAreaRentSum;
    /**
     * 土地闲置面积
     */
    private BigDecimal landAreaIdleSum;
    /**
     * 闲置率
     */
    private BigDecimal idlePercent;
    /**
     * 子列表
     */
    private List<LandIdleStatPo> children;

    public LandIdleStatPo() {
        this.areaNo = "";
        this.areaName = "";
        this.cityNo = "";
        this.cityName = "";
        this.idleCount = 0;
        this.totalLandAreaSum = BigDecimal.ZERO;
        this.landAreaSelfUseSum = BigDecimal.ZERO;
        this.landAreaUnusableSum = BigDecimal.ZERO;
        this.landAreaRentSum = BigDecimal.ZERO;
        this.landAreaIdleSum = BigDecimal.ZERO;
        this.idlePercent = BigDecimal.ZERO;
        this.children = new ArrayList<>();
    }

    public LandIdleStatPo(String areaNo, String areaName) {
        this.areaNo = areaNo;
        this.areaName = areaName;
        this.cityNo = areaNo;
        this.cityName = areaName;
        this.idleCount = 0;
        this.totalLandAreaSum = BigDecimal.ZERO;
        this.landAreaSelfUseSum = BigDecimal.ZERO;
        this.landAreaUnusableSum = BigDecimal.ZERO;
        this.landAreaRentSum = BigDecimal.ZERO;
        this.landAreaIdleSum = BigDecimal.ZERO;
        this.idlePercent = BigDecimal.ZERO;
        this.children = new ArrayList<>();
    }

    public void update(LandIdleStatPo po) {
        this.idleCount = this.idleCount + po.idleCount;
        this.totalLandAreaSum = this.totalLandAreaSum.add(po.totalLandAreaSum);
        this.landAreaSelfUseSum = this.landAreaSelfUseSum.add(po.landAreaSelfUseSum);
        this.landAreaUnusableSum = this.landAreaUnusableSum.add(po.landAreaUnusableSum);
        this.landAreaRentSum = this.landAreaRentSum.add(po.landAreaRentSum);
        this.landAreaIdleSum = this.landAreaIdleSum.add(po.landAreaIdleSum);
        if (BigDecimal.ZERO.compareTo(this.landAreaRentSum.add(this.landAreaIdleSum)) != 0) {
            this.idlePercent = this.landAreaIdleSum
                    .divide(this.landAreaRentSum.add(this.landAreaIdleSum), 4, RoundingMode.HALF_DOWN);
        } else {
//            this.idlePercent = null;
            this.idlePercent = BigDecimal.ZERO;
        }
        this.children.add(po);
    }
}
