package com.example.pojo.dto;

import com.example.enums.ListBuildingRepairMonthOrderEnum;
import com.example.enums.OrderEnum;
import com.example.utils.Page;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.springframework.util.StringUtils;

import javax.validation.Valid;
import javax.validation.constraints.NotNull;
import java.net.URLDecoder;
import java.nio.charset.StandardCharsets;

@NoArgsConstructor
@Data
public class ListBuildingRepairMonthDto {
    @Valid
    @NotNull
    private Page page;
    @Valid
    @NotNull
    private ListBuildingRepairMonthMapDTO map;

    @NoArgsConstructor
    @Data
    public static class ListBuildingRepairMonthMapDTO {
        @Schema(description = "账期", example = "202312")
        @NotNull
        private Integer statisticalMonth;
        @Schema(description = "二级组织机构id")
        private String city;
        @Schema(description = "三级级组织机构id")
        private String county;
        @Schema(description = "排序字段", example = "erpCreditedAmount")
        private ListBuildingRepairMonthOrderEnum sidx;
        @Schema(description = "排序方式", example = "desc")
        private OrderEnum order;
        @Schema(description = "局址别名")
        private String alias;
        @Schema(description = "局址编号")
        private String code;
        @Schema(description = "投资主体")
        private String investmentEntity;
    }

    public ListBuildingRepairMonthDto(ListBuildingRepairMonthMapDTO map) {
        if (StringUtils.hasText(map.city)) {
            map.city = URLDecoder.decode(map.city, StandardCharsets.UTF_8);
        }
        if (StringUtils.hasText(map.county)) {
            map.county = URLDecoder.decode(map.county, StandardCharsets.UTF_8);
        }
        if (StringUtils.hasText(map.alias)) {
            map.alias = URLDecoder.decode(map.alias, StandardCharsets.UTF_8);
        }
        if (StringUtils.hasText(map.getInvestmentEntity())) {
            map.investmentEntity = URLDecoder.decode(map.getInvestmentEntity(), StandardCharsets.UTF_8);
        }
        this.map = map;
    }
}
