package com.example.pojo.dto;

import com.example.enums.ListLandOrderEnum;
import com.example.enums.OrderEnum;
import com.example.utils.Page;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.springframework.util.StringUtils;

import javax.validation.Valid;
import javax.validation.constraints.NotNull;
import java.net.URLDecoder;
import java.nio.charset.StandardCharsets;

@NoArgsConstructor
@Data
public class ListLandDto {
    @Valid
    @NotNull
    private Page page;
    @Valid
    private ListLandMapDTO map;

    @NoArgsConstructor
    @Data
    public static class ListLandMapDTO {
        @Schema(description = "账期", example = "202312")
        private Integer statisticalMonth;
        @Schema(description = "二级组织机构id")
        private String city;
        @Schema(description = "三级级组织机构id")
        private String county;
        @Schema(description = "排序字段")
        private ListLandOrderEnum sidx;
        @Schema(description = "排序方式")
        private OrderEnum order;
        @Schema(description = "局址别名")
        private String buildingNameAlias;
        @Schema(description = "局址编号")
        private String code;
    }

    public ListLandDto(ListLandMapDTO map) {
        if (StringUtils.hasText(map.city)) {
            map.city = URLDecoder.decode(map.city, StandardCharsets.UTF_8);
        }
        if (StringUtils.hasText(map.county)) {
            map.county = URLDecoder.decode(map.county, StandardCharsets.UTF_8);
        }
        if (StringUtils.hasText(map.buildingNameAlias)) {
            map.buildingNameAlias = URLDecoder.decode(map.buildingNameAlias, StandardCharsets.UTF_8);
        }
        this.map = map;
    }
}
