package com.example.pojo.vo;

import com.example.entity.house.HouseBuildingPo;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;

import java.math.BigDecimal;
import java.text.DecimalFormat;

@Data
public class ListBuildingVo {
    @Schema(description = "账期", example = "202312")
    private Integer statisticalMonth;
    @Schema(description = "资产所属单位一级")
    private String province;
    @Schema(description = "资产所属单位二级")
    private String city;
    @Schema(description = "资产所属单位三级")
    private String county;
    @Schema(description = "建筑别名")
    private String buildingAias;
    @Schema(description = "建筑面积㎡")
    private BigDecimal buildingArea;
    @Schema(description = "建筑面积自用㎡")
    private BigDecimal buildingAreaUseArea;
    @Schema(description = "建筑面积出租㎡")
    private BigDecimal buildingAreaRentArea;
    @Schema(description = "建筑面积闲置㎡")
    private BigDecimal buildingAreaIdelArea;
    @Schema(description = "建筑面积不可使用㎡")
    private BigDecimal buildingAreaUnavailable;
    @Schema(description = "标准地址")
    private String standardAddress;
    @Schema(description = "建筑用途")
    private String buildingUse;
    @Schema(description = "得房率")
    private String buildingRate;
    @Schema(description = "上级局址名称")
    private String parentBuildingName;
    @Schema(description = "上级土地名称")
    private String parentLandName;
    @Schema(description = "房屋来源")
    private String buildingSource;
    @Schema(description = "取得日期")
    private String getDate;
    @Schema(description = "房龄开始年份")
    private Integer buildingStartYear;
    @Schema(description = "投资主体")
    private String investmentEntity;
    @Schema(description = "管理层级")
    private String managementHierarchy;
    @Schema(description = "房屋结构")
    private String buildingStructure;
    @Schema(description = "楼层总数")
    private String totalNumberOfFloors;
    @Schema(description = "是否临街")
    private String buildingFaceStreet;
    @Schema(description = "是否有院落")
    private String courtyard;
    @Schema(description = "整栋是否独有")
    private String wholeBuilding;
    @Schema(description = "是否有房产证")
    private String premisesPermit;
    @Schema(description = "无房产证原因")
    private String noPremisesPermitReason;
    @Schema(description = "未关联资产")
    private String unrelatedAssets;
    @Schema(description = "资产编号")
    private String assetCode;
    @Schema(description = "资产标签号")
    private String astsLabe;
    @Schema(description = "使用状态")
    private String useState;
    @Schema(description = "权属状态")
    private String ownershipStatus;
    @Schema(description = "建筑占地面积(㎡)")
    private BigDecimal buildingFloorArea;
    @Schema(description = "使用面积(㎡)")
    private BigDecimal useArea;
    @Schema(description = "使用面积-自用(㎡)")
    private BigDecimal useAreaSelfUseArea;
    @Schema(description = "使用面积-出租(㎡)")
    private BigDecimal useAreaRentArea;
    @Schema(description = "使用面积-闲置(㎡)")
    private BigDecimal useAreaIdelArea;
    @Schema(description = "使用面积-不可使用(㎡)")
    private BigDecimal useAreaUnavailableArea;
    @Schema(description = "楼长姓名")
    private String landManageName;
    @Schema(description = "楼长所在单位")
    private String landManageCompany;
    @Schema(description = "房屋经度")
    private BigDecimal buildingLongitude;
    @Schema(description = "房屋纬度")
    private BigDecimal buildingDimension;
    @Schema(description = "房屋实际产权")
    private String buildingActualPropertyRights;
    @Schema(description = "局址编码")
    private String buildingAddressNumber;
    @Schema(description = "局址别名")
    private String buildingNameAlias;
    @Schema(description = "地段")
    private String areaSector;

    public ListBuildingVo(HouseBuildingPo po) {
        this.statisticalMonth = po.getYearMonth();
        this.province = po.getFirstUnit();
        this.city = po.getAreaName();
        this.county = po.getCityName();
        this.buildingAias = po.getBuildingName();
        this.buildingArea = po.getBuildingArea();
        this.buildingAreaUseArea = po.getBuildingAreaSelfUse();
        this.buildingAreaRentArea = po.getBuildingAreaRent();
        this.buildingAreaIdelArea = po.getBuildingAreaIdle();
        this.buildingAreaUnavailable = po.getBuildingAreaUnusable();
        this.standardAddress = po.getAddress();
        this.buildingUse = po.getBuildingUse();
        this.buildingRate = po.getHousingAcquisitionRate() != null
                ? new DecimalFormat("#.00%").format(po.getHousingAcquisitionRate()) : null;
        this.parentBuildingName = po.getSiteName();
        this.parentLandName = po.getLandName();
        this.buildingSource = po.getHousingSource();
        this.getDate = po.getAcquisitionDate();
        this.buildingStartYear = po.getHouseYearBegan();
        this.investmentEntity = po.getInvestor();
        this.managementHierarchy = po.getManagementLevel();
        this.buildingStructure = po.getBuildingStructure();
        this.totalNumberOfFloors = po.getTotalFloors();
        this.buildingFaceStreet = po.getFrontage();
        this.courtyard = po.getCourtyard();
        this.wholeBuilding = po.getWholeBuilding();
        this.premisesPermit = po.getPropertyOwnershipCertificate();
        this.noPremisesPermitReason = po.getNoPropertyOwnershipCertificateReason();
        this.unrelatedAssets = po.getUnrelatedAssets();
        this.assetCode = po.getAssetsNum();
        this.astsLabe = po.getAssetsTagNum();
        this.useState = po.getUsageStatus();
        this.ownershipStatus = po.getOwnershipStatus();
        this.buildingFloorArea = po.getFloorArea();
        this.useArea = po.getUsableArea();
        this.useAreaSelfUseArea = po.getUsableAreaSelfUse();
        this.useAreaRentArea = po.getUsableAreaRent();
        this.useAreaIdelArea = po.getUsableAreaIdle();
        this.useAreaUnavailableArea = po.getUsableAreaUnusable();
        this.landManageName = po.getCommunityAssistantName();
        this.landManageCompany = po.getCommunityAssistantUnit();
        this.buildingLongitude = po.getLngJt();
        this.buildingDimension = po.getLatJt();
        this.buildingActualPropertyRights = po.getPropertyOwner();
        this.buildingAddressNumber = po.getSiteNum();
        this.buildingNameAlias = po.getSiteName();
        this.areaSector = po.getAreaSector();
    }
}
