package com.example.service.house;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.example.common.PageVo;
import com.example.common.Rsp;
import com.example.dao.WzOtnAreaDao;
import com.example.entity.OtnAreaEntity;
import com.example.entity.house.HouseSitePo;
import com.example.pojo.bo.ListHouseSiteBo;
import com.example.pojo.dto.ListSiteNameDto;
import com.example.pojo.dto.ListSiteNumDto;
import com.example.pojo.vo.ListSiteNameVo;
import com.example.pojo.vo.ListSiteNumVo;
import com.example.utils.R;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import java.net.URLDecoder;
import java.nio.charset.StandardCharsets;
import java.util.List;

@Slf4j
@Service
public class HouseWzOtnAreaService {
    private final WzOtnAreaDao wzOtnAreaDao;

    public HouseWzOtnAreaService(WzOtnAreaDao wzOtnAreaDao) {
        this.wzOtnAreaDao = wzOtnAreaDao;
    }

    public R getCityOption(String id) {
        if (StringUtils.hasText(id)) {
            id = URLDecoder.decode(id, StandardCharsets.UTF_8);
        }
        if ("0".equals(id) || "全省".equals(id)) {
            id = "018";
        }
        List<OtnAreaEntity> list = wzOtnAreaDao.listByParentId(id);
        return R.ok().put("list", list);
    }

    public Rsp<PageVo<ListSiteNameVo>> listSiteName(ListSiteNameDto dto) {
        if ("全省".equals(dto.getMap().getCity())) {
            dto.getMap().setCity(null);
            dto.getMap().setCounty(null);
        }
        ListHouseSiteBo bo = new ListHouseSiteBo();
        bo.setAreaNo(dto.getMap().getCity());
        bo.setCityNo(dto.getMap().getCounty());
        bo.setSiteName(dto.getMap().getAlias());
        Page<HouseSitePo> page = new Page<>(dto.getPage().getPageNum(), dto.getPage().getPageSize());
        List<HouseSitePo> list = wzOtnAreaDao.listHouseSite(page, bo);
        List<ListSiteNameVo> vos = list.stream().map(ListSiteNameVo::new).toList();
        PageVo<ListSiteNameVo> pageVo = new PageVo<>(vos, page);
        return Rsp.ok(pageVo);
    }

    public Rsp<PageVo<ListSiteNumVo>> listSiteNum(ListSiteNumDto dto) {
        if ("全省".equals(dto.getMap().getCity())) {
            dto.getMap().setCity(null);
            dto.getMap().setCounty(null);
        }
        ListHouseSiteBo bo = new ListHouseSiteBo();
        bo.setAreaNo(dto.getMap().getCity());
        bo.setCityNo(dto.getMap().getCounty());
        bo.setSiteNum(dto.getMap().getCode());
        Page<HouseSitePo> page = new Page<>(dto.getPage().getPageNum(), dto.getPage().getPageSize());
        List<HouseSitePo> list = wzOtnAreaDao.listHouseSite(page, bo);
        List<ListSiteNumVo> vos = list.stream().map(ListSiteNumVo::new).toList();
        PageVo<ListSiteNumVo> pageVo = new PageVo<>(vos, page);
        return Rsp.ok(pageVo);
    }
}
