package com.example.service.impl;

import com.example.controller.WzHouseMaintenaCostController;
import com.example.dao.WzHouseMaintenaCostDao;
import com.example.entity.OtnAreaEntity;
import com.example.entity.WzHouseMaintenaCostEntity;
import com.example.entity.WzScoreVo;
import com.example.entity.vo.DailyModifyVo;
import com.example.entity.vo.HighFrequencyVo;
import com.example.service.WzHouseMaintenaCostService;
import com.example.service.WzOtnAreaService;
import com.example.utils.Query;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.LocalDate;
import java.time.format.DateTimeFormatter;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Service
public class WzHouseMaintenaCostServiceImpl implements WzHouseMaintenaCostService {

    @Autowired
    private WzHouseMaintenaCostDao wzHouseMaintenaCostDao;
    @Autowired
    private WzOtnAreaService otnAreaService;

    @Override
    public List<WzHouseMaintenaCostEntity> queryList(Map<String, Object> map) {
        dealMap(map);
        return wzHouseMaintenaCostDao.queryList(map);
    }

    @Override
    public int queryTotal(Map<String, Object> map) {
        dealMap(map);
        return wzHouseMaintenaCostDao.queryTotal(map);
    }

    @Override
    public int queryTotal1(Map<String, Object> map) {
        dealMap(map);
        return wzHouseMaintenaCostDao.queryTotal1(map);
    }

    @Override
    public List<WzHouseMaintenaCostEntity> queryHighPrice(Map map) {
        dealMap(map);
        List<WzHouseMaintenaCostEntity> list= wzHouseMaintenaCostDao.queryHighPrice(map);
        return list;
    }

    @Override
    public List<DailyModifyVo> queryDailyModify(Query query) {
        dealMap(query);
        return  wzHouseMaintenaCostDao.queryDailyModify(query);
    }

    public  List<WzScoreVo> queryDailyModifyByScore(Map<String, Object> query){
        dealMap(query);
        query.put("erpCreditedAmount", 10000);
        List<DailyModifyVo> dailyLiist=  wzHouseMaintenaCostDao.queryDailyModify(query);
        List<HighFrequencyVo> highList=  wzHouseMaintenaCostDao.queryHighFrequencyByScore(query);

        Map<String,List<DailyModifyVo>> cityMap=new HashMap<>();
        for (DailyModifyVo dailyModifyVo : dailyLiist) {
            List<DailyModifyVo> list;
            if(cityMap.get(dailyModifyVo.getCity())!=null){
                list=cityMap.get(dailyModifyVo.getCity());
                list.add(dailyModifyVo);
            }else{
                list=new ArrayList<>();
                list.add(dailyModifyVo);
            }
            cityMap.put(dailyModifyVo.getCity(),list);
        }


        Map<String,List<HighFrequencyVo>> higMap=new HashMap<>();
        for (HighFrequencyVo highFrequencyVo : highList) {
            List<HighFrequencyVo> list;
            if(higMap.get(highFrequencyVo.getCity())!=null){
                list=higMap.get(highFrequencyVo.getCity());
                list.add(highFrequencyVo);
            }else{
                list=new ArrayList<>();
                list.add(highFrequencyVo);
            }
            higMap.put(highFrequencyVo.getCity(),list);
        }

        //对cityList 进行排序
        List<OtnAreaEntity> areaList=otnAreaService.getCityOption("018");
        List<WzScoreVo> orderList=new ArrayList<>();
        int highNum=0;
        int dailyNum=0;
        for (OtnAreaEntity otnAreaEntity : areaList) {
            WzScoreVo wzScoreVo=new WzScoreVo();
            wzScoreVo.setCity(otnAreaEntity.getName());
            Map<String, List<HighFrequencyVo>> map=new HashMap<>();
            if(higMap.get(otnAreaEntity.getName())!=null){
                List<HighFrequencyVo> itemList=higMap.get(otnAreaEntity.getName());
                for (HighFrequencyVo highFrequencyVo : itemList) {
                    List<HighFrequencyVo> list;
                    if(map.get(highFrequencyVo.getBuildingAlias())!=null){
                        list=map.get(highFrequencyVo.getBuildingAlias());
                        list.add(highFrequencyVo);
                    }else{
                        list=new ArrayList<>();
                        list.add(highFrequencyVo);
                    }
                    map.put(highFrequencyVo.getBuildingAlias(),list);
                }
                int num=0;
                for (Map.Entry<String, List<HighFrequencyVo>> entry : map.entrySet()) {
                    if(entry.getValue().size()>1){
                        num++;
                        highNum++;
                    }
                }
                wzScoreVo.setHighNum(num);
                if(cityMap.get(otnAreaEntity.getName())!=null){
                    dailyNum+=cityMap.get(otnAreaEntity.getName()).size();
                }
                wzScoreVo.setDailyNum(cityMap.get(otnAreaEntity.getName())==null?0:cityMap.get(otnAreaEntity.getName()).size());
                orderList.add(wzScoreVo);
            }
        }

        WzScoreVo wzScoreVo=new WzScoreVo();
        wzScoreVo.setCity("全省");
        String dailyValue=WzHouseMaintenaCostController.toThousands((dailyNum*1.0)/(orderList.size()*1.0),true);
        wzScoreVo.setDailyNum(Double.valueOf(dailyValue));
        String highValue=WzHouseMaintenaCostController.toThousands((highNum*1.0)/(orderList.size()*1.0),true);
        wzScoreVo.setHighNum(Double.valueOf(highValue));
        wzScoreVo.setChildren(orderList);
        List<WzScoreVo> resultList=new ArrayList<>();
        resultList.add(wzScoreVo);
        return resultList;
    }

    @Override
    public List<HighFrequencyVo> queryHighFrequency(Query query) {
        dealMap(query);
        return wzHouseMaintenaCostDao.queryHighFrequency(query);
    }

    @Override
    public int queryDailyModifyTotal(Query query1) {
        dealMap(query1);
        return wzHouseMaintenaCostDao.queryDailyModifyTotal(query1);
    }

    @Override
    public List<WzHouseMaintenaCostEntity> queryList1(Map map) {
        dealMap(map);
        return wzHouseMaintenaCostDao.queryList1(map);
    }

    @Override
    public List<String> getBuildingNameCode(Query query) {
        dealMap(query);
        return wzHouseMaintenaCostDao.getBuildingNameCode(query);
    }

    @Override
    public List<String> getBuildingNameAlias(Query query) {
        dealMap(query);
        return wzHouseMaintenaCostDao.getBuildingNameAlias(query);
    }

    @Override
    public int getBuildingNameAliasTotal(Query query) {
        dealMap(query);
        return wzHouseMaintenaCostDao.getBuildingNameAliasTotal(query);
    }

    @Override
    public int queryBuildDetailByCodeTotal(Query query) {
        dealMap(query);
        return wzHouseMaintenaCostDao.queryBuildDetailByCodeTotal(query);
    }




    public void  dealMap(Map<String, Object> map){
        if(map.get("city")!=null&&!map.get("city").toString().equals("全省")&&!map.get("city").toString().equals("")){
            OtnAreaEntity city = otnAreaService.queryObjectById(map.get("city").toString());
            map.put("city",city.getName());
        }
        if(map.get("city")!=null&&map.get("city").toString().equals("全省")){
            map.remove("city");
        }
        if(map.get("investmentEntity")!=null&&map.get("investmentEntity").toString().equals("投资主体")){
            map.remove("investmentEntity");
        }
        if(map.get("city")!=null&&map.get("city").toString().equals("")){
            map.remove("city");
        }
        if(map.get("county")!=null&&!map.get("county").toString().equals("区县")&&!map.get("county").toString().equals("")){
            OtnAreaEntity city = otnAreaService.queryObjectById(map.get("county").toString());
            map.put("county",city.getName());
        }
        if(map.get("county")!=null&&map.get("county").toString().equals("区县")){
            map.remove("county");
        }
        if(map.get("county")!=null&&map.get("county").toString().equals("")){
            map.remove("county");
        }
        if(map.get("statisticalMonth1")!=null&&!map.get("statisticalMonth1").toString().equals("")){
            String statisticalMonth1 = (String) map.get("statisticalMonth1");
            if (map.get("statisticalMonth") == null || StringUtils.isBlank((String) map.get("statisticalMonth"))) {
                String statisticalMonth =
                        LocalDate.parse(statisticalMonth1 + "01", DateTimeFormatter.ofPattern("yyyyMMdd"))
                                .withDayOfYear(1).format(DateTimeFormatter.ofPattern("yyyyMM"));
                map.put("statisticalMonth", statisticalMonth);
            }
            map.put("statisticalMonth1",Integer.valueOf(map.get("statisticalMonth1").toString()));
        }else{
            map.remove("statisticalMonth1");
        }
        if(map.get("statisticalMonth")!=null&&!map.get("statisticalMonth").toString().equals("")&&!map.get("statisticalMonth").toString().equals("账期")){
            map.put("statisticalMonth",Integer.valueOf(map.get("statisticalMonth").toString()));
        }else{
            map.remove("statisticalMonth");
        }
    }


}
